# Opsicos Python SDK

Install this private SDK using pip and Git:

```bash
pip install "git+https://YOUR_GITHUB_USERNAME:YOUR_PERSONAL_ACCESS_TOKEN@github.com/1-Tawsif-1/opsicos-api.git#subdirectory=sdks/python"
